import prisma from "../../prisma"
import { rejectionErrorFns, rejectionErrors } from "../errors"
import type { IdToken } from "./createTokenDB"
import sendError, { API } from "./sendError"
import type { Token } from "@prisma/client"

async function getTokenDB<T>(
  context: API<T>,
  token: IdToken,
  next: (tokenDB: Token) => void
) {
  const { id, type } = token
  // Find refresh token in DB
  const tokenDB = await prisma.token.findUnique({
    where: {
      id,
    },
  })
  if (!tokenDB) return sendError(context, rejectionErrorFns.tokenNotFound(type))

  if (tokenDB.used) return sendError(context, rejectionErrors.tokenUsed)

  await prisma.token.update({
    where: {
      id,
    },
    data: {
      used: true,
    },
  })

  // await logging('Old token has been invalidated.', ['debug'], req)

  return next(tokenDB)
}

export default getTokenDB
